# @gdnsl/plugin-function

> gdnsl plugin for function commands

Latest version **0.0.55** (published 2023-02-27) · MIT license · 0 weekly downloads

## Install

```sh
npm install @gdnsl/plugin-function
pnpm add @gdnsl/plugin-function
yarn add @gdnsl/plugin-function
bun add @gdnsl/plugin-function
```

Provides the command `plugin-function`.

## Health

**Score 25/100 (F)** — status: abandoned.

Positive: has types; no vulnerabilities; high quality score.

Warnings: low downloads; no esm support; pre 1.0.

Negative: abandoned; low maintenance score.

## Facts

| | |
|---|---|
| Version | 0.0.55 |
| Published | 2023-02-27 |
| First published | 2023-01-02 |
| Weekly downloads | 0 |
| License | MIT |
| TypeScript types | bundled |
| Module format | CommonJS |
| Node | >=14.0.0 |
| Dependencies | 6 |
| Unpacked size | 76.4 KB |
| Known vulnerabilities | 0 |
| Install scripts | no |
| Author | Dino Lozina |
| Maintainers | macrometa |
| Keywords | oclif |

## Links

- npm: https://www.npmjs.com/package/@gdnsl/plugin-function
- Repository: https://github.com/Macrometacorp/gdnsl
- Issues: https://github.com/Macrometacorp/gdnsl/issues
- npm.io page: https://npm.io/package/@gdnsl/plugin-function

## Dependencies (6)

- [jsc8](https://npm.io/package/jsc8.md) ^1.0.0
- [chalk](https://npm.io/package/chalk.md) ^4.1.1
- [@oclif/core](https://npm.io/package/@oclif/core.md) ^1
- [@gdnsl/cli-utils](https://npm.io/package/@gdnsl/cli-utils.md) ^0.0.55
- [@oclif/plugin-help](https://npm.io/package/@oclif/plugin-help.md) ^5
- [console-table-printer](https://npm.io/package/console-table-printer.md) ^2.9.0

## Alternatives

- [@salesforce/cli](https://npm.io/package/@salesforce/cli.md) — 389.7K weekly downloads
- [@mintlify/cli](https://npm.io/package/@mintlify/cli.md) — 208.9K weekly downloads
- [@grafana/e2e-selectors](https://npm.io/package/@grafana/e2e-selectors.md) — 128.7K weekly downloads
- [mintlify](https://npm.io/package/mintlify.md) — 112.0K weekly downloads
- [@intlayer/cli](https://npm.io/package/@intlayer/cli.md) — 22.8K weekly downloads

## Recent versions

- 0.0.55 (latest) — 2023-02-27
- 0.0.52 — 2023-01-02
- 0.0.51 — 2023-01-02

## README

@gdnsl/plugin-function
=================

gdnsl plugin for function commands

<!-- toc -->
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->

# Usage

  <!-- usage -->
```sh-session
$ npm install -g @gdnsl/plugin-function
$ @gdnsl/plugin-function COMMAND
running command...
$ @gdnsl/plugin-function (--version)
@gdnsl/plugin-function/0.0.55 darwin-x64 node-v14.20.0
$ @gdnsl/plugin-function --help [COMMAND]
USAGE
  $ @gdnsl/plugin-function COMMAND
...
```
<!-- usagestop -->

# Commands

  <!-- commands -->
* [`@gdnsl/plugin-function function info NAME`](#gdnslplugin-function-function-info-name)
* [`@gdnsl/plugin-function function invoke NAME`](#gdnslplugin-function-function-invoke-name)
* [`@gdnsl/plugin-function function list`](#gdnslplugin-function-function-list)
* [`@gdnsl/plugin-function function remove NAME`](#gdnslplugin-function-function-remove-name)
* [`@gdnsl/plugin-function help [COMMAND]`](#gdnslplugin-function-help-command)
* [`@gdnsl/plugin-function metadata add`](#gdnslplugin-function-metadata-add)
* [`@gdnsl/plugin-function metadata delete`](#gdnslplugin-function-metadata-delete)
* [`@gdnsl/plugin-function metadata get`](#gdnslplugin-function-metadata-get)
* [`@gdnsl/plugin-function metadata modify`](#gdnslplugin-function-metadata-modify)
* [`@gdnsl/plugin-function query-worker deploy NAME QUERYWORKERNAME [TYPE] [ENVIRONMENT]`](#gdnslplugin-function-query-worker-deploy-name-queryworkername-type-environment)
* [`@gdnsl/plugin-function stream-adhoc-query deploy NAME STREAMWORKERNAME`](#gdnslplugin-function-stream-adhoc-query-deploy-name-streamworkername)
* [`@gdnsl/plugin-function stream-publisher deploy NAME STREAMWORKERNAME STREAMNAME [TYPE] [ENVIRONMENT]`](#gdnslplugin-function-stream-publisher-deploy-name-streamworkername-streamname-type-environment)

## `@gdnsl/plugin-function function info NAME`

Get edge function information.

```
USAGE
  $ @gdnsl/plugin-function function info [NAME] [-h] [-c <value>] [--fabric <value>] [-o json]

FLAGS
  -c, --config=<value>  gdnsl config file (default is ./gdnsl.yaml).
  -h, --help            Help to get function information.
  -o, --output=(json)   Output format. Only json is allowed.
  --fabric=<value>      Name of the fabric. Default will be "_system".

DESCRIPTION
  Get edge function information.

EXAMPLES
  # Get edge function information
  gdnsl function info
```

## `@gdnsl/plugin-function function invoke NAME`

Invoke function.

```
USAGE
  $ @gdnsl/plugin-function function invoke [NAME] [-h] [-c <value>] [--fabric <value>] [-p <value>]

FLAGS
  -c, --config=<value>    gdnsl config file (default is ./gdnsl.yaml).
  -h, --help              Help to invoke function.
  -p, --param=<value>...  key=value pair representing the parameters of function
  --fabric=<value>        Name of the fabric. Default will be "_system".

DESCRIPTION
  Invoke function.

EXAMPLES
  # Invoke function without parameters
  gdnsl function invoke functionName
  # Invoke function with parameters
  gdnsl function invoke functionName --param "offset=0" "limit=10"
```

## `@gdnsl/plugin-function function list`

List edge worker functions.

```
USAGE
  $ @gdnsl/plugin-function function list [-h] [-c <value>] [--fabric <value>] [-o json]

FLAGS
  -c, --config=<value>  gdnsl config file (default is ./gdnsl.yaml).
  -h, --help            Help to list functions.
  -o, --output=(json)   Output format. Only json is allowed.
  --fabric=<value>      Name of the fabric. Default will be "_system".

DESCRIPTION
  List edge worker functions.

EXAMPLES
  # List all edge functions.
  gdnsl function list
```

## `@gdnsl/plugin-function function remove NAME`

Remove function.

```
USAGE
  $ @gdnsl/plugin-function function remove [NAME] [-h] [-c <value>] [--fabric <value>]

FLAGS
  -c, --config=<value>  gdnsl config file (default is ./gdnsl.yaml).
  -h, --help            Help to remove function.
  --fabric=<value>      Name of the fabric. Default will be "_system".

DESCRIPTION
  Remove function.

EXAMPLES
  # Remove function
  gdnsl function delete functionName
```

## `@gdnsl/plugin-function help [COMMAND]`

Display help for @gdnsl/plugin-function.

```
USAGE
  $ @gdnsl/plugin-function help [COMMAND] [-n]

ARGUMENTS
  COMMAND  Command to show help for.

FLAGS
  -n, --nested-commands  Include all nested commands in the output.

DESCRIPTION
  Display help for @gdnsl/plugin-function.
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v5.1.11/src/commands/help.ts)_

## `@gdnsl/plugin-function metadata add`

Add edge worker metadata.

```
USAGE
  $ @gdnsl/plugin-function metadata add [-h] [-c <value>] [--fabric <value>] [-t akamai] [-a <value>] [-b <value>]
    [-s <value>] [-t <value>] [-h <value>] [-i <value>] [-g <value>]

FLAGS
  -a, --access-token=<value>      Akamai access token
  -b, --baseurl=<value>           Akamai endpoint url
  -c, --config=<value>            gdnsl config file (default is ./gdnsl.yaml).
  -g, --group-id=<value>          Akamai property group id
  -h, --help                      Help to add metadata.
  -h, --hostname=<value>          Akamai property host name
  -i, --resource-tier-id=<value>  Specify the Akamai tier used for your integration. Dynamic Computer should be 200 and
                                  Basic Compute should be 100.
  -s, --client-secret=<value>     Part of Akamai credentials - Secret
  -t, --client-token=<value>      Part of Akamai credentials - Token
  -t, --type=<option>             [default: akamai] Specifies type of the edge worker. Values - "akamai". Default -
                                  "akamai"
                                  <options: akamai>
  --fabric=<value>                Name of the fabric. Default will be "_system".

DESCRIPTION
  Add edge worker metadata.

EXAMPLES
  # Add edge worker metadata integration parameters
  gdnsl metadata add --access-token xxxx --baseurl xxxx --client-secret xxxx --client-token xxxx --hostname xxxx --resource-tier-id xxxx --group-id xxxx
```

## `@gdnsl/plugin-function metadata delete`

Delete edge worker Metadata.

```
USAGE
  $ @gdnsl/plugin-function metadata delete [-h] [-c <value>] [--fabric <value>]

FLAGS
  -c, --config=<value>  gdnsl config file (default is ./gdnsl.yaml).
  -h, --help            Help to delete metadata.
  --fabric=<value>      Name of the fabric. Default will be "_system".

DESCRIPTION
  Delete edge worker Metadata.

EXAMPLES
  # Delete Edge Worker Metadata integration parameters
  gdnsl metadata delete
```

## `@gdnsl/plugin-function metadata get`

List edge worker metadata.

```
USAGE
  $ @gdnsl/plugin-function metadata get [-h] [-c <value>] [--fabric <value>] [-o json]

FLAGS
  -c, --config=<value>  gdnsl config file (default is ./gdnsl.yaml).
  -h, --help            Help to get metadata.
  -o, --output=(json)   Output format. Only json is allowed.
  --fabric=<value>      Name of the fabric. Default will be "_system".

DESCRIPTION
  List edge worker metadata.

EXAMPLES
  # List all edge worker metadata integration parameters
  gdnsl metadata get
```

## `@gdnsl/plugin-function metadata modify`

Modify edge worker metadata.

```
USAGE
  $ @gdnsl/plugin-function metadata modify [-h] [-c <value>] [--fabric <value>] [-t akamai] [-a <value>] [-b <value>]
    [-s <value>] [-t <value>] [-h <value>] [-i <value>] [-g <value>]

FLAGS
  -a, --access-token=<value>      Akamai access token
  -b, --baseurl=<value>           Akamai endpoint url
  -c, --config=<value>            gdnsl config file (default is ./gdnsl.yaml).
  -g, --group-id=<value>          Akamai property group id
  -h, --help                      Help to modify metadata.
  -h, --hostname=<value>          Akamai property host name
  -i, --resource-tier-id=<value>  Specify the Akamai tier used for your integration. Dynamic Computer should be 200 and
                                  Basic Compute should be 100.
  -s, --client-secret=<value>     Part of Akamai credentials - Secret
  -t, --client-token=<value>      Part of Akamai credentials - Token
  -t, --type=<option>             [default: akamai] Specifies type of the edge worker. Values - "akamai". Default -
                                  "akamai"
                                  <options: akamai>
  --fabric=<value>                Name of the fabric. Default will be "_system".

DESCRIPTION
  Modify edge worker metadata.

EXAMPLES
  # Modify edge worker metadata integration parameters
  gdnsl metadata modify --access-token xxxx --baseurl xxxx --client-secret xxxx --client-token xxxx --hostname xxxx --resource-tier-id xxxx --group-id xxxx
```

## `@gdnsl/plugin-function query-worker deploy NAME QUERYWORKERNAME [TYPE] [ENVIRONMENT]`

Deploy the query worker to the edge worker environment.

```
USAGE
  $ @gdnsl/plugin-function query-worker deploy [NAME] [QUERYWORKERNAME] [TYPE] [ENVIRONMENT] [-h] [-c <value>] [--fabric
    <value>] [--type akamai] [--environment PRODUCTION|STAGING] [-o json]

FLAGS
  -c, --config=<value>    gdnsl config file (default is ./gdnsl.yaml).
  -h, --help              Help to deploy query-worker.
  -o, --output=(json)     Output format. Only json is allowed.
  --environment=<option>  [default: PRODUCTION] Specifies deployment environment. Values - "PRODUCTION" or "STAGING".
                          Default - "PRODUCTION"
                          <options: PRODUCTION|STAGING>
  --fabric=<value>        Name of the fabric. Default will be "_system".
  --type=<option>         [default: akamai] Specifies type of the edge worker. Values - "akamai". Default - "akamai"
                          <options: akamai>

DESCRIPTION
  Deploy the query worker to the edge worker environment.

EXAMPLES
  # Deploy the query worker to the edge.
  gdnsl query-worker deploy edgeworkername queryworker
  # Deploy the query worker to the edge with another type
  gdnsl query-worker deploy edgeworkername queryworker --type akamai
  # Deploy the query worker to the edge with another type and different environment
  gdnsl query-worker deploy edgeworkername queryworker --type akamai --environment PRODUCTION
```

## `@gdnsl/plugin-function stream-adhoc-query deploy NAME STREAMWORKERNAME`

Deploy the stream adhoc query to the edge worker environment.

```
USAGE
  $ @gdnsl/plugin-function stream-adhoc-query deploy [NAME] [STREAMWORKERNAME] [-h] [-c <value>] [--fabric <value>] [--type
    akamai] [--environment PRODUCTION|STAGING] [-o json]

FLAGS
  -c, --config=<value>    gdnsl config file (default is ./gdnsl.yaml).
  -h, --help              Help to deploy stream-adhoc-query.
  -o, --output=(json)     Output format. Only json is allowed.
  --environment=<option>  [default: PRODUCTION] Specifies deployment environment. Values - "PRODUCTION" or "STAGING".
                          Default - "PRODUCTION"
                          <options: PRODUCTION|STAGING>
  --fabric=<value>        Name of the fabric. Default will be "_system".
  --type=<option>         [default: akamai] Specifies type of the edge worker. Values - "akamai". Default - "akamai"
                          <options: akamai>

DESCRIPTION
  Deploy the stream adhoc query to the edge worker environment.

EXAMPLES
  # Deploy the stream adhoc query to the edge.
  gdnsl stream-adhoc-query deploy edgeworkername streamworkername
  # Deploy the stream adhoc query to the edge with another type
  gdnsl stream-adhoc-query deploy edgeworkername streamworkername --type akamai
  # DDeploy the stream adhoc query to the edge with another type and different environment
  gdnsl stream-adhoc-query deploy edgeworkername streamworkername --type akamai --environment PRODUCTION
```

## `@gdnsl/plugin-function stream-publisher deploy NAME STREAMWORKERNAME STREAMNAME [TYPE] [ENVIRONMENT]`

Deploy the stream publisher to the edge worker environment.

```
USAGE
  $ @gdnsl/plugin-function stream-publisher deploy [NAME] [STREAMWORKERNAME] [STREAMNAME] [TYPE] [ENVIRONMENT] [-h] [-c
    <value>] [--fabric <value>] [--type akamai] [--environment PRODUCTION|STAGING] [-o json]

FLAGS
  -c, --config=<value>    gdnsl config file (default is ./gdnsl.yaml).
  -h, --help              Help to deploy stream-publisher.
  -o, --output=(json)     Output format. Only json is allowed.
  --environment=<option>  [default: PRODUCTION] Specifies deployment environment. Values - "PRODUCTION" or "STAGING".
                          Default - "PRODUCTION"
                          <options: PRODUCTION|STAGING>
  --fabric=<value>        Name of the fabric. Default will be "_system".
  --type=<option>         [default: akamai] Specifies type of the edge worker. Values - "akamai". Default - "akamai"
                          <options: akamai>

DESCRIPTION
  Deploy the stream publisher to the edge worker environment.

EXAMPLES
  # Deploy the stream publisher to the edge.
  gdnsl stream-publisher deploy edgeworkername streamworkername streamname
  # Deploy the stream publisher to the edge with another type
  gdnsl stream-publisher deploy edgeworkername streamworkername streamname --type akamai
  # DDeploy the stream publisher to the edge with another type and different environment
  gdnsl stream-publisher deploy edgeworkername streamworkername streamname --type akamai --environment PRODUCTION
```
<!-- commandsstop -->

---
_Source: https://npm.io/package/@gdnsl/plugin-function · Machine-readable twin of the npm.io package page. Health data is recomputed on every publish._
